@@ -289,6 +289,7 @@ impl server::FreeFunctions for Rustc {
         // FIXME: track env var accesses
         // https://github.com/rust-lang/rust/pull/71858
     }
+    fn track_path(&mut self, _path: &str) {}
 }
 
 impl server::TokenStream for Rustc {
@@ -493,6 +494,10 @@ impl server::Literal for Rustc {
         None
     }
 
+    fn to_string(&mut self, literal: &Self::Literal) -> String {
+        literal.to_string()
+    }
+
     fn integer(&mut self, n: &str) -> Self::Literal {
         let n = match n.parse::<i128>() {
             Ok(n) => n.to_string(),
@@ -569,8 +574,8 @@ impl server::Literal for Rustc {
         literal.id
     }
 
-    fn set_span(&mut self, _literal: &mut Self::Literal, _span: Self::Span) {
-        // FIXME handle span
+    fn set_span(&mut self, literal: &mut Self::Literal, span: Self::Span) {
+        literal.id = span;
     }
 
     fn subspan(
@@ -640,7 +645,14 @@ impl server::Span for Rustc {
         // let MySpanData(span) = self.span_interner.get(span.0);
         unimplemented!()
     }
-
+    fn save_span(&mut self, _span: Self::Span) -> usize {
+        // FIXME stub
+        0
+    }
+    fn recover_proc_macro_span(&mut self, _id: usize) -> Self::Span {
+        // FIXME stub
+        tt::TokenId::unspecified()
+    }
     /// Recent feature, not yet in the proc_macro
     ///
     /// See PR:
@@ -665,8 +677,9 @@ impl server::Span for Rustc {
         // FIXME handle span
         LineColumn { line: 0, column: 0 }
     }
-    fn join(&mut self, _first: Self::Span, _second: Self::Span) -> Option<Self::Span> {
-        None
+    fn join(&mut self, first: Self::Span, _second: Self::Span) -> Option<Self::Span> {
+        // Just return the first span again, because some macros will unwrap the result.
+        Some(first)
     }
     fn resolved_at(&mut self, _span: Self::Span, _at: Self::Span) -> Self::Span {
         // FIXME handle span
@@ -677,6 +690,14 @@ impl server::Span for Rustc {
         // FIXME handle span
         tt::TokenId::unspecified()
     }
+
+    fn after(&mut self, _self_: Self::Span) -> Self::Span {
+        tt::TokenId::unspecified()
+    }
+
+    fn before(&mut self, _self_: Self::Span) -> Self::Span {
+        tt::TokenId::unspecified()
+    }
 }
 
 impl server::MultiSpan for Rustc {
